# AUTOGENERATED! DO NOT EDIT! File to edit: ../00_core.ipynb.

# %% auto 0
__all__ = ['minus_one', 'add_one']

# %% ../00_core.ipynb 3
from fastcore.utils import *

# %% ../00_core.ipynb 5
def minus_one(): pass

# %% ../00_core.ipynb 7
def add_one(x): return x + 1



# AUTOGENERATED! DO NOT EDIT! File to edit: ../01_activations.ipynb.

# %% auto 0
__all__ = ['activation']

# %% ../01_activations.ipynb 3
from fastcore.utils import *

# %% ../01_activations.ipynb 5
#def foo(): pass

# %% ../01_activations.ipynb 7
def activation(
        x: int # number only
    ):
    return x + 10



# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'xrsrke',
                'author_email': 'xariusdrake@hotmail.com',
                'black_formatting': 'False',
                'branch': 'master',
                'clean_ids': 'True',
                'copyright': '2022 ownwards, xrsrke',
                'custom_quarto_yml': 'False',
                'custom_sidebar': 'False',
                'description': 'Neural network from scratch',
                'doc_baseurl': '/neural-network-from-scratch',
                'doc_host': 'https://xrsrke.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/xrsrke/neural-network-from-scratch',
                'jupyter_hooks': 'True',
                'keywords': 'nbdev jupyter notebook python',
                'language': 'English',
                'lib_name': 'neural-network-from-scratch',
                'lib_path': 'neural_network_from_scratch',
                'license': 'apache2',
                'min_python': '3.7',
                'nbs_path': '.',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'repo': 'neural-network-from-scratch',
                'status': '3',
                'title': 'neural-network-from-scratch',
                'tst_flags': 'notest',
                'user': 'xrsrke',
                'version': '0.0.1'},
  'syms': { 'neural_network_from_scratch.activation': { 'neural_network_from_scratch.activation.activation': 'https://xrsrke.github.io/neural_network_from_scratch.activation.html#activation'},
            'neural_network_from_scratch.core': { 'neural_network_from_scratch.core.add_one': 'https://xrsrke.github.io/neural_network_from_scratch.core.html#add_one',
                                                  'neural_network_from_scratch.core.minus_one': 'https://xrsrke.github.io/neural_network_from_scratch.core.html#minus_one'}}}